### Description

In experimental book design, design is not reducible to aesthetics but an integral part of the story. Closely intertwined, design and writing tend to go hand in hand. Moving beyond the division of form and content (and digital and printed books) that prevails in conventional publishing opens space for experimental book projects that explore design as a mode of reasoning. 

### Full description

Book design, layout, and typography shape how readers navigate books in print and on-screen. Especially in scholarly publishing however design is often treated as an afterthought that comes at the end of the publishing pipeline after the final manuscript has been approved. Good book design, in this understanding, is tasked with optimising knowledge transmission and should ideally be noticeable to the reader only insofar as it creates a smooth reading experience. In contrast to the idea that *good* book design must be all but invisible, experimental book design tends to center design as a mode of articulation that evolve alongside and therefore cannot be separated from writing. [Mark Sharple](https://www.routledge.com/How-We-Write-Writing-as-Creative-Design/Sharples/p/book/9780415185875) (1999) declares the time ripe for 'designed literature,' under which he understands a renewed integration of writing, illustration and design "to achieve effects on the reader." Graphic designers [Pauliina Nykänen and Arja Karhumaa](https://www.routledge.com/The-Experimental-Book-Object-Materiality-Media-Design/Sjoberg-Keskinen-Karhumaa/p/book/9781032368818?srsltid=AfmBOorscremrleB-cDlb44BsY9nWZK9Ouj90tLfMlJ0USTFknX68-vx) (2024) liken the notion that typography should enable effortless reading to a systematic reduction of "the body of the reader to the metonymy of the reading mind or eye." Following graphic designer [Silvia Sfligiotti's](https://www.researchgate.net/publication/355221045_Why_we_need_more_somatic_culture_in_design) (2021) appeal for an embodied approach to design, they call on experimental book designers to reacquaint the reading eye with the situated body. Pointing out that the binary between reading-mind and absent-body mirrors the modernist division between form and content she aims to design for more embodied forms of reading that challenge mind/body, digital/print binaries. Drawing on more than 15 years of experience editing scholarly multimedia, [Cheryl Ball and Douglas Eyman](https://doi.org/10.3998/3336451.0018.406) (2015) argue that "you cannot separate form and content---or the written content from its design. (...) This process of removing content runs counter to the purpose of scholarly multimedia in which form and content are inseparable." They and others conclude that separating form from content "result\[s\] in a loss of meaning" ([Helm, 2018](https://kairos.technorhetoric.net/23.1/inventio/helms/)). [Wojciech Drag](https://www.routledge.com/The-Experimental-Book-Object-Materiality-Media-Design/Sjoberg-Keskinen-Karhumaa/p/book/9781032368818?srsltid=AfmBOorscremrleB-cDlb44BsY9nWZK9Ouj90tLfMlJ0USTFknX68-vx) (2024) extends the observation that something is lost when the form / content binary is enforced to database driven publishing. Referring to [computational publishing](https://compendium.copim.ac.uk/practices/57), he notes that "Designing, writing, composition blurr" when they are "partially assigned to computational processes." Summarizing these lines of thought, [Janneke Adema, Marcel Mars, and Tobias Steiner (2021)](https://doi.org/10.5281/zenodo.4486645) define experimental design books as books in which design performs an integral part of the argument.

### Experimental uses

Digital publishing enables **non-linear interactive storytelling**. The [*Feral Atlas*](https://feralatlas.supdigital.org/) is an example of a design-heavy, ambitious, scholarly, interactive publication. The non-linear publication format mirrors the authors' argument that human-built infrastructures comprise feral ecologies developing and spreading beyond human control. [*As I Remember It: Teachings (ɁəmstɑɁɑw) from the Life of a Sliammon Elder*](http://publications.ravenspacepublishing.org/as-i-remember-it/index) is another example of a non-linear, immersive online publication that allows readers to take different pathways. The book is positioned as an Indigenous ɬaʔamɩn territory within the internet, where ʔəms tɑʔɑw (translated as "our teachings") are shared and protected under ɬaʔamɩn guest-host protocol. unlike the *Feral Atlas*, which relies on a custom built backend, *As I Remember It* has been produced with the open source publication platform [Scalar](https://compendium.copim.ac.uk/tools/20) that enables the design of non-linear onlinepublications.

**Web-to-Print (W2P)** provides maybe the most exciting development in book design. Designing layouts with advanced HTML to PDF conversion tools (often built on [paged.js](https://compendium.copim.ac.uk/tools/128)) and Cascading Style Sheets (CSS) enables design workflows that generate high-quality and print-ready PDFs from HTML content more or less automatically once they have been set up. Disentangling the design process from fixed outputs and proprietary software means that different formats can easily be generated at different points in the publishing process, with vast implications for book publishing. Book design becomes about designing the processes and parameters that generate various outputs rather than the design of fixed layouts. Being able to dynamically generate a variety of PDF and ebook outputs from a single HTML file means that the source document of the book can be continuously updated without causing labour and cost-intense design changes every time a change is made. This enables **more processual modes of publishing and book design.** Providing both dynamically generated digital outputs and necessarily fixed print outputs radically decenters the notion of singular original versions. The publishing project [pirate.care.syllabus](https://syllabus.pirate.care/) uses HTML to print to make a growing collection of syllabi of extra-institutional care practices available for download and print. While the Pirate Care team uses W2P to generate book print files, they have also created large-scale posters for exhibitions demonstrating the workflow's versatility. The book project [*Mutant Assembly*](https://compendium.copim.ac.uk/books/154) grew out of an assembly of artists, writers, dancers and researchers departing from Senegal's post-independence, utopian educational projects to rethink the possibilities of school today. The publication is designed as a mutating document and uses W2P to generate different versions or mutations of the book whenever a user exports content for download or print.

Rendering content dynamically to different formats and media implies another huge shift from the design of fixed, highly controllable layouts to **[fluid, elastic, adaptive or responsive layouts](https://stackoverflow.com/questions/11482518/what-is-the-differenence-between-fixed-vs-fluid-vs-elastic-layout-vs-responsiv)** that change, stretch, and reorganise dramatically to adapt single-source content to changing screen or media sizes.

**Pad-to-PDF publishing** is a version of W2P publishing. It combines the capabilities of online pads such as [etherpad](https://etherpad.org/) with tools such as [Paged.js](https://pagedjs.org/) that create PDF outputs from HMTL content. One notable editing environment that combines pads collective writing capablitities with W2P is [octomode](https://compendium.copim.ac.uk/tools/141), which, in the words of the developers, "imagined a space in which the artificial boundaries of writing and design can be crossed; where writing, editing, and designing can be done in one environment simultaneously, allowing the format to influence the matter and vice versa."

**Feral print-on-demand**. Some book projects, such as *Mutant Assembly* and *Pirate Care*, *[On Publishing: Graphic Designers Who Publish](https://onpublishing.page/)* or *[Hybrid Publishing Systems](https://hybrid.publishing.systems/)*, encourage readers to generate unique print PDFs for download and home printing. Such a distributed, open approach to print-on-demand counteracts the quasi-monopoly of global PoD services with a practice that we might think of as feral print-on-demand. Further inspiration can be found in artistic publication projects. Paul Soulellis' curated table of publication projects [Printed Web 1-5](https://docs.google.com/document/d/10i-h2SsQnA17eeOWZ24nnuZdOJ9FtJ_1_OjpwgAwUus/edit) provides an inspiring collection of artistic publications that use feral home printing of web materials. [Publication Studios](https://www.publicationstudio.biz/about/) offers another approach to on-demand printing beyond standardised commercial production. The network of community-run printers and publishers prints and binds "books one at a time on-demand," combining craft and distributed digital production in ways that speak to scholarly concerns with embodiment and materiality.

**Designing for dynamic composition.** The scope of design is changing with the digital transformation of books, and this, like any radical transformation, is accompanied by nostalgia (for print) and fears. [Jon Bath](https://doi.org/10.22230/src.2012v3n3a90) (2012), articulates a concern with the lackluster typographic quality of digital publications, which is shared by many designers and connoisseurs of printed matter. Bath laments that "The ability to include streaming video has taken precedence over being able to fix an awkwardly spaced "i", observing that "many electronic reading interfaces and/or the tools used to create them do not support the basic practices of "good" typography, such as fine granularity in typeface choices or letter spacing." What is lost in digital environments, with their many and varied parameters, such as different screen resolutions, fluid layouts or conventions for rendering type, is the designer's fine-grained control over issues such as awkwardly spaced characters. This loss of control signals a change from designing fixed book objects accompanied by notions of good design to designing parameters for dynamically rendered, distributed objects.

**Designing Encounters - Decolonising book design.** Having long advocated for a non-object-centred conception of books, Johanna Drucker's work on bibliographical alterities asks if we can understand (and design) books as contact zones, or conditional documents that come into being through encounters. Drawing on work in contact studies, a field of research that explores the contact zones between settler colonialism and indigenous forms of knowledge, Drucker observes that the notion of a stable book object as the highest achievement of bibliographic culture is a colonial notion because it devalues forms of knowledge that are alterior to western ideas of what a book is. Drawing on [Elizabeth Boone's and Walter Mignolo's](https://www.dukeupress.edu/writing-without-words) (1994) work, Drucker argues that decolonising book history requires shifting *"...outside its modern or western frames to grasp an alternative conception—in which a book is conceived as a distributed object, not a thing, but a set of intersecting events, material conditions, and activities."* ([Drucker, 2014](https://doi.org/10.14195/2182-8830_2-1_1)).

Drucker points out that the possibilities of digitally born books, like a decolonial theory of book history, require rethinking books as networked, distributed events. Linking Drucker's approach to decolonializing book history to design, one can experiment with books as contact zones or conditional documents that come into being through encounters. An invitation for designers to move from designing and rarifying singular book objects to designing, or orchestrating book-constituting processes or performances.

### Considerations

**Budget for design**. It is still rare to have a design budget for scholarly publications, and there are not many academic publishers that are dedicated to well-designed books. Securing funds for design in scholarly institutions is tricky, and book design tends to be underfunded and treated as an afterthought by many academic presses. Planning an experimental book project without design expertise will likely undermine the project's quality and possibilities.

**Consider design from the start**. Partly because it is difficult to budget for design even within well-funded scholarly projects, design often comes as an afterthought, late in the process, financed via left-over funds. Tara McPherson, founding editor of the design focused online book production platform [Scalar](https://compendium.copim.ac.uk/tools/20), demonstrates in her article ["Designing for Difference"](https://doi.org/10.1215/10407391-2420039) how design can enable the mutual constitution of content and form if it is considered from the outset.

**Digital book design is coding is designing is writing...** In book experiments, exploring how a specific design looks and feels typically requires an iterative workflow. Working with designers who are familiar with coding and responsive layouts rather than fixed designs will make collaboration with developers and authors easier and allow project teams to test different versions.

**Unique and open?** Commitments to open tools and platforms can be in tension with the desire to create stand-out, project-specific designs. Negotiating this tension is part of the politics of experimental publishing. Developing plug-ins for existing platforms is one option for working with this tension. Going one step further, some publishing platforms such as [Scalar](https://compendium.copim.ac.uk/tools/20) offer APIs that allow projects to develop custom frontends that utilise the capabilities of the publishing platform as a backend. (Nicole Starosielski, Erik Loyer, and Shane Brennan's *[Surfacing](http://surfacing.in/?image=baler-beach)* book project, for example, deploys a custom frontend based on Scalar).

**For now, or forever?** Online custom designs often appear dated shortly after release and can be hard to archive and maintain. Projects that do not have the resources for long-term maintenance should take the ephemeral nature of design-heavy digital experiments into account from the get-go. While projects might decide not to aim for preservation, this only becomes an informed decision if the project team considers how design decisions affect preservation from the get-go (see the entry on
the practice of [preserving](https://compendium.copim.ac.uk/practices/54)).

**Finding designers** dedicated to book experimentation, scholarly work and open source tools can be challenging. There is a growing number of practitioners, institutes and communities at the intersection of the academy, coding, design and publishing, where authors and publishers might find suitable collaborators, tools and inspiration. The [XPUB](https://xpub.nl) experimental publishing master program at the Piet Zwart Institute in Rotterdam and the [Creative Computing Institute](https://www.arts.ac.uk/creative-computing-institute) at the University of the Arts London, and Central Saint Martins, [Graphic Communication Design program](https://researchers.arts.ac.uk/849-rebecca-ross) are notable for bridging design, coding and publishing experiments. The [varia](https://varia.zone/en/) collective in Rotterdam and the [Constant](https://constantvzw.org/site/) collective in Brussels, and [Hackers and Designers](https://www.hackersanddesigners.nl/s/Publishing) in Amsterdam, [Electric Book Works](https://electricbookworks.com/) in Cape Town, the development team behind [Scalar](https://compendium.copim.ac.uk/tools/20) and the[PrePostPrint](https://prepostprint.org/) collective are but some of the communities that nurture experimental book projects and develop tools to support this work at the intersection of aesthetics, politics, and scholarship.

### Further reading

Drucker, Johanna. 'Distributed and Conditional Documents: Conceptualizing Bibliographical Alterities'. *Matlit Revista Do Programa de Doutoramento Em Materialidades Da Literatura* 2, no. 1 (8 November 2014): 11--29. [https://doi.org/10.14195/2182-8830_2-1_1](https://doi.org/10.14195/2182-8830_2-1_1).

Hamamoto, Christopher, and Jon Sueda, eds. 2023. *On Publishing: Graphic Designers Who Publish*. [https://onpublishing.page/](https://onpublishing.page/).

McPherson, Tara. 2014. 'Designing for Difference'. *Differences* 25 (1): 177–88. [https://doi.org/10.1215/10407391-2420039](https://doi.org/10.1215/10407391-2420039).

Sjöberg, Sami, Mikko Keskinen, and Arja Karhumaa, eds. *The Experimental Book Object: Materiality, Media, Design*. New York, NY: Routledge, 2024. [https://doi.org/10.4324/9781003334293](https://doi.org/10.4324/9781003334293).

Soulellis, Paul, ed. (2014, 2015, 2017) *Printed Web 1–5* [https://docs.google.com/document/d/10i-h2SsQnA17eeOWZ24nnuZdOJ9FtJ_1_OjpwgAwUus/edit](https://docs.google.com/document/d/10i-h2SsQnA17eeOWZ24nnuZdOJ9FtJ_1_OjpwgAwUus/edit). Tumblr page [https://libraryoftheprintedweb.tumblr.com/](https://libraryoftheprintedweb.tumblr.com/).